@@ -13,36 +13,32 @@
 #include "entry_p.h"
 #include "ui/widgetquestionlistener.h"
 
+#if KNEWSTUFF_BUILD_DEPRECATED_SINCE(5, 29)
 namespace KNS3
 {
 class DownloadManagerPrivate
 {
 public:
-    DownloadManager *q;
-    KNSCore::Engine *engine;
+    DownloadManager *const q;
+    KNSCore::Engine *const engine;
 
-    DownloadManagerPrivate(DownloadManager *q)
-        : q(q)
+    DownloadManagerPrivate(DownloadManager *qq)
+        : q(qq)
         , engine(new KNSCore::Engine)
-        , isInitialized(false)
-        , checkForUpdates(false)
-        , checkForInstalled(false)
-        , doSearch(false)
-        , page(0)
-        , pageSize(100)
-    {}
+    {
+    }
     ~DownloadManagerPrivate()
     {
         delete engine;
     }
 
-    bool isInitialized;
-    bool checkForUpdates;
-    bool checkForInstalled;
-    bool doSearch;
+    bool isInitialized = false;
+    bool checkForUpdates = false;
+    bool checkForInstalled = false;
+    bool doSearch = false;
 
-    int page;
-    int pageSize;
+    int page = 0;
+    int pageSize = 100;
 
     void init(const QString &configFile);
     void _k_slotProvidersLoaded();
@@ -131,12 +127,12 @@ void DownloadManagerPrivate::_k_slotEntriesLoaded(const KNSCore::EntryInternal::
     for (const KNSCore::EntryInternal &entry : entries) {
         result.append(EntryPrivate::fromInternal(&entry));
     }
-    emit q->searchResult(result);
+    Q_EMIT q->searchResult(result);
 }
 
 void KNS3::DownloadManagerPrivate::_k_slotEntryStatusChanged(const KNSCore::EntryInternal &entry)
 {
-    emit q->entryStatusChanged(EntryPrivate::fromInternal(&entry));
+    Q_EMIT q->entryStatusChanged(EntryPrivate::fromInternal(&entry));
 }
 
 void DownloadManager::installEntry(const KNS3::Entry &entry)
@@ -190,9 +186,10 @@ void DownloadManager::setSearchTerm(const QString &searchTerm)
     d->engine->setSearchTerm(searchTerm);
 }
 
-void KNS3::DownloadManager::fetchEntryById(const QString& id)
+void KNS3::DownloadManager::fetchEntryById(const QString &id)
 {
     d->engine->fetchEntryById(id);
 }
 
 #include "moc_downloadmanager.cpp"
+#endif
